#!/bin/sh

#Copyright (C) 2006 - 2009 NTT DATA Corporation
#
#This program is free software; you can redistribute it and/or
#Modify it under the terms of the GNU General Public License
#as published by the Free Software Foundation, version 2.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details

. /opt/hinemos/hinemos.cfg

if [ -f ${HINEMOS_PG_PID} ] ; then

        PG_PID=`head -1 ${HINEMOS_PG_PID}`
        ps -p ${PG_PID} > /dev/null && TMP=1
        if [ "$TMP" ] ; then
                echo ""
                echo "======================================================"
                echo "ERROR another postmaster may be runnning."
                echo "pid file (${HINEMOS_PG_PID}) is exist."
                echo "======================================================"
                exit 24
        else
                rm -f ${HINEMOS_PG_PID}
        fi
fi

${PG}/bin/pg_ctl start -w -D ${PGDATA} > /dev/null 2>&1
